Skip to contents

Deprecated functions

Usage

remove_non_significative_outliers(
  ws_path,
  threshold = 0.3,
  reference = FALSE,
  estimation = FALSE,
  verbose = TRUE
)

Arguments

ws_path, threshold, reference, estimation, verbose

Parameters.

Value

The same value as returned by the corresponding non-deprecated function. The returned object represents an encoded identifier for a spreadsheet series or collection.