This function creates a complete project structure for a seasonal adjustment production workflow. It initializes an R project, sets up useful directories, configuration files, and development tools.
The generated structure is designed for workflows based on the 'rjdverse'.
Examples
project_path <- tempfile(pattern = "my-project")
if (FALSE) { # \dontrun{
# Create a new project
init_env(path = project_path)
} # }