Skip to contents

Launches an interactive Shiny application to explore and compare seasonal adjustment results stored in a data.frame returned by compare().

Usage

run_app(data, ...)

Arguments

data

A data.frame returned by compare(), containing the columns ws, SAI, series, date, and value.

...

Additional arguments passed to shiny::shinyApp().

Value

Runs a Shiny app in the R session (no return value).

Examples

if (FALSE) { # \dontrun{
df <- compare(path1, path2)
run_app(df)
} # }